==> docx4j-openxml-objects-8.3.11-sources.jar: org/docx4j/wml/PPr.java <==
/*
 *  Copyright 2007-2013, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.wml; 

import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CT_PPr complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_PPr">
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.openxmlformats.org/wordprocessingml/2006/main}CT_PPrBase">
 *       &lt;sequence>
 *         &lt;element name="rPr" type="{http://schemas.openxmlformats.org/wordprocessingml/2006/main}CT_ParaRPr" minOccurs="0"/>
 *         &lt;element name="sectPr" type="{http://schemas.openxmlformats.org/wordprocessingml/2006/main}CT_SectPr" minOccurs="0"/>
 *         &lt;element name="pPrChange" type="{http://schemas.openxmlformats.org/wordprocessingml/2006/main}CT_PPrChange" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_PPr", propOrder = {
    "rPr",
    "sectPr",
    "pPrChange"
})
@XmlRootElement(name = "pPr")
public class PPr
    extends PPrBase
{

    protected ParaRPr rPr;
    protected SectPr sectPr;
    protected CTPPrChange pPrChange;

    /**
     * Gets the value of the rPr property.
     * 
     * @return
     *     possible object is
     *     {@link ParaRPr }
     *     
     */
    public ParaRPr getRPr() {
        return rPr;
    }

    /**
     * Sets the value of the rPr property.
     * 
     * @param value
     *     allowed object is
     *     {@link ParaRPr }
     *     
     */
    public void setRPr(ParaRPr value) {
        this.rPr = value;
    }

    /**
     * Gets the value of the sectPr property.
     * 
     * @return
     *     possible object is
     *     {@link SectPr }
     *     
     */
    public SectPr getSectPr() {
        return sectPr;
    }

    /**
     * Sets the value of the sectPr property.
     * 
     * @param value
     *     allowed object is
     *     {@link SectPr }
     *     
     */
    public void setSectPr(SectPr value) {
        this.sectPr = value;
    }

    /**
     * Gets the value of the pPrChange property.
     * 
     * @return
     *     possible object is
     *     {@link CTPPrChange }
     *     
     */
    public CTPPrChange getPPrChange() {
        return pPrChange;
    }

    /**
     * Sets the value of the pPrChange property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTPPrChange }
     *     
     */
    public void setPPrChange(CTPPrChange value) {
        this.pPrChange = value;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> docx4j-openxml-objects-11.4.9-sources.jar: org/docx4j/wml/PPr.java <==
/*
 *  Copyright 2007-2013, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.wml; 

import jakarta.xml.bind.Unmarshaller;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CT_PPr complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_PPr">
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.openxmlformats.org/wordprocessingml/2006/main}CT_PPrBase">
 *       &lt;sequence>
 *         &lt;element name="rPr" type="{http://schemas.openxmlformats.org/wordprocessingml/2006/main}CT_ParaRPr" minOccurs="0"/>
 *         &lt;element name="sectPr" type="{http://schemas.openxmlformats.org/wordprocessingml/2006/main}CT_SectPr" minOccurs="0"/>
 *         &lt;element name="pPrChange" type="{http://schemas.openxmlformats.org/wordprocessingml/2006/main}CT_PPrChange" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_PPr", propOrder = {
    "rPr",
    "sectPr",
    "pPrChange"
})
@XmlRootElement(name = "pPr")
public class PPr
    extends PPrBase
{

    protected ParaRPr rPr;
    protected SectPr sectPr;
    protected CTPPrChange pPrChange;

    /**
     * Gets the value of the rPr property.
     * 
     * @return
     *     possible object is
     *     {@link ParaRPr }
     *     
     */
    public ParaRPr getRPr() {
        return rPr;
    }

    /**
     * Sets the value of the rPr property.
     * 
     * @param value
     *     allowed object is
     *     {@link ParaRPr }
     *     
     */
    public void setRPr(ParaRPr value) {
        this.rPr = value;
    }

    /**
     * Gets the value of the sectPr property.
     * 
     * @return
     *     possible object is
     *     {@link SectPr }
     *     
     */
    public SectPr getSectPr() {
        return sectPr;
    }

    /**
     * Sets the value of the sectPr property.
     * 
     * @param value
     *     allowed object is
     *     {@link SectPr }
     *     
     */
    public void setSectPr(SectPr value) {
        this.sectPr = value;
    }

    /**
     * Gets the value of the pPrChange property.
     * 
     * @return
     *     possible object is
     *     {@link CTPPrChange }
     *     
     */
    public CTPPrChange getPPrChange() {
        return pPrChange;
    }

    /**
     * Sets the value of the pPrChange property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTPPrChange }
     *     
     */
    public void setPPrChange(CTPPrChange value) {
        this.pPrChange = value;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}
